@@ -645,19 +645,18 @@ effect:
             for e in  epochs:
                 #generate  random noise as an input  to  initialize the  generator
                 hist= self.gan.train_on_batch(noisevector, y_gen)
-                print(hist)
+
                 if self.diagnostics:
-                    discloss.append( mu*hist[1] )
-                    chi2.append( hist[2] )
+                    discloss.append( hist[0] )
+                    chi2.append( hist[1] )
 
             img = self.get_image(noisevector)
             img = (img+1)/2
             if self.diagnostics:
                 self.give_imgrec_diagnostics(hist, chi2, discloss, r, epochs, mu)
                 self.save_image_from_noise(noisevector, name=f'{self.dir}/Image_restart{r}.pdf')
-
-            Chi2s.append(hist[2])
-            DisLoss.append(hist[1])
+            Chi2s.append(hist[1])
+            DisLoss.append(hist[0])
             Images.append(img[:,::-1])
             Vectors.append(noisevector)
 
